@@ -1,6 +1,6 @@
 package Mail::Audit::Attach;
 
-# Copyright (c) 2002 Christian Renz <crenz@web42.com>. All rights reserved.
+# Copyright (c) 2002-2005 Christian Renz <crenz@web42.com>. All rights reserved.
 # This program is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself.
 
@@ -9,7 +9,7 @@ use vars qw($VERSION @ISA $ERROR);
 use MIME::Entity;
 use File::Spec;
 
-$VERSION = '0.93';
+$VERSION = '0.95';
 
 @ISA = qw(MIME::Entity);
 
@@ -221,6 +221,7 @@ sub _remove_attachments {
 
 __END__
 
+=encoding utf-8
 
 =head1 NAME
 
@@ -263,6 +264,17 @@ This is a Mail::Audit plugin which provides easy access to files
 attached to mail messages. Besides Mail::Audit, it requires the
 C<MIME::Entity> module.
 
+=head2 CONSTRUCTOR
+
+=over 4
+
+=item C<new>
+
+This constructor is called by L<Mail::Audit>; it should not be necessary
+to create a Mail::Audit::Attach object manually.
+
+=back
+
 =head2 METHODS IN MAIL::AUDIT
 
 =over 4
@@ -275,6 +287,10 @@ Returns the number of attachments found
 
 Returns a reference to a list of attachment objects
 
+=item C<error>
+
+Returns a string with an error message (if an error ocurred).
+
 =item C<remove_attachments>
 
 Removes attachments from the mail that match the criteria specified
@@ -360,13 +376,57 @@ Note that the attachment is not removed.
 C<Mail::Audit::Attach::error> will return an error message if an
 action failed (currently only set by C<save>).
 
+=head1 HISTORY
+
+=item 0.95, 2010-02-26
+
+    - Created GitHub repository
+    - Fixed RT#19546: Added missing dependency MIME::Base64
+
+=item 0.94  Sun Jun 05 23:00:00 2005
+
+    - Updated distribution to more modern format.
+    - Added POD tests.
+
+=item 0.93  Sat Apr 14 00:30:00 2003
+
+    - Mail::Audit->save died when passed an empty location. Fixed.
+      location is now optional.
+    - Now uses File::Spec for more portability
+    - Introduced Mail::Audit::error (used by save)
+    - Localized $_ where used
+
+=item 0.92  Sat Feb  8 13:00:00 2003
+
+	- Now relies on MIME::Head to recognize attachments.
+	  "Never try to be too clever."
+	- No more warnings.
+
+=item 0.91  Thu Feb  6 22:30:00 2003
+
+  - Now recognizes attachments with Content-Disposition inline,
+    but a given filename. This became necessary because Netscape
+   	Communicator and other clients send their attachments that way.
+
+	  Thanks to Jeff Engelhardt and Vladimir Parkhaev for bringing
+          this to my attention.
+
+=item 0.90  Sat Jun  1 19:35:24 2002
+
+	- original version; created by h2xs 1.19
+
+
+=head1 DEVELOPMENT NOTES
+
+Please report any bugs using the CPAN RT system. The development repository for this module is hosted on GitHub: L<http://github.com/crenz/Mail-Audit-Attach/>.
+
 =head1 AUTHOR
 
 Christian Renz <crenz@web42.com>
 
 =head1 LICENSE
 
-Copyright (C) 2002-2003 Christian Renz <crenz@web42.com>
+Copyright (C) 2002-2010 Christian Renz <crenz@web42.com>
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
